@@ -1,5 +1,6 @@
 from swatchtime import SwatchTime
 
 def main():
-	print("1")
-	print(SwatchTime().get())
\ No newline at end of file
+	print(SwatchTime().get())
+
+main()
\ No newline at end of file
